@@ -52,11 +52,17 @@ def register_mongodb(
                         f"Added database collection '{coll_name}'."
                     )
 
-                    # Add indices
+                    # Add indexes
                     if coll_conf.indexes is not None:
+                        # Remove already created indexes if any
+                        coll_conf.client.drop_indexes()
                         for index in coll_conf.indexes:
                             if index.keys is not None:
-                                coll_conf.client.create_index(**index.dict())
+                                coll_conf.client.create_index(
+                                    index.keys, **index.options)
+                        logger.info(
+                            f"Indexes created for collection '{coll_name}'."
+                        )
 
     return conf
 
